@@ -1804,7 +1804,7 @@ class RatingV2Extension(Extension):
         }
 
         # args: service
-        pages, found, aggs, _ = Page.provider_by_context(
+        items, total, aggs, _ = Page.provider_by_context(
             is_searchable=True,
             is_redirect=False,
             country=current_user.country_full,
@@ -1818,11 +1818,13 @@ class RatingV2Extension(Extension):
 
         t = current_app.jinja_env.get_template('_ext-rating_casinos.html')
         s = t.render(
-            pages=pages, 
-            found=f'{found} matching casinos', 
-            service=service, 
+            items=items, 
+            total=total, 
             count=count,
+            percent=20,
+            service=service, 
             tags=tags,
+            cnt_casinos_total='1000',
             aggs=process_aggs(aggs, 'provider_tags', tags_enabled),
         )
         return s
